GAN tutorial with PyTorch
=========================

.. include:: ../../../tutorials/distributed-ml/torch-tutorial-GAN/README.md
   :parser: myst_parser.sphinx_


Python files 
------------------

train.py
++++++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-tutorial-GAN/train.py
   :language: python

simpleGAN.py
+++++++++++++++
.. literalinclude:: ../../../tutorials/distributed-ml/torch-tutorial-GAN/simpleGAN.py
   :language: python

Shell scripts
--------------

slurm.sh
++++++++++++
.. literalinclude:: ../../../tutorials/distributed-ml/torch-tutorial-GAN/slurm.sh
   :language: bash


runall.sh
++++++++++++++++
.. literalinclude:: ../../../tutorials/distributed-ml/torch-tutorial-GAN/runall.sh
   :language: bash

